<?php

/**
 * @file
 * Contains the min_timeline style plugin.
 */

/**
 * Style plugin to render each item on the timeline.
 *
 * @ingroup views_style_plugins
 */
class min_timeline_style_plugin extends views_plugin_style_list {

  /**
   * {@inheritdoc}
   */
  public function option_definition() {
    $options = parent::option_definition();
    $options['mode'] = ['default' => 'horizontal'];
    $options['forceVerticalMode'] = ['default' => 700];
    $options['verticalTrigger'] = ['default' => '15%'];
    $options['verticalStartPosition'] = ['default' => 'left'];
    $options['horizontalStartPosition'] = ['default' => 'top'];
    $options['visibleItems'] = ['default' => 4];
    $options['moveItems'] = ['default' => 1];
    $options['startIndex'] = ['default' => 0];
    $options['rtlMode'] = ['default' => FALSE];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function options_form(&$form, &$form_state) {
    $form['mode'] = array(
      '#type' => 'select',
      '#title' => t('Mode'),
      '#options' => [
        'horizontal' => t('Horizontal'),
        'veritical' => t('Vertical'),
      ],
      '#default_value' => $this->options['mode'],
      '#description' => t('Selected the layout of the timeline'),
    );

    $form['forceVerticalMode'] = array(
      '#type' => 'textfield',
      '#title' => t('Force Vertical Mode'),
      '#default_value' => $this->options['forceVerticalMode'],
      '#description' => t('Specify the screen size at which breakpoint the horizontal timeline should swtich to the Vertical layout.'),
    );

    $form['verticalTrigger'] = array(
      '#type' => 'textfield',
      '#title' => t('Vertical Trigger'),
      '#default_value' => $this->options['verticalTrigger'],
      '#description' => t('Set the distance from the bottom to trigger the vertical mode.'),
    );

    $form['verticalStartPosition'] = array(
      '#type' => 'select',
      '#title' => t('Vertical Start Position'),
      '#options' => [
        'left' => t('Left'),
        'right' => t('Right'),
      ],
      '#default_value' => $this->options['verticalStartPosition'],
      '#description' => t('Specify the alignment of the first item when the timline is in the Vertical mode'),
    );

    $form['horizontalStartPosition'] = array(
      '#type' => 'select',
      '#title' => t('Horizontal Start Position'),
      '#options' => [
        'top' => t('Top'),
        'bottom' => t('Bottom'),
      ],
      '#default_value' => $this->options['horizontalStartPosition'],
      '#description' => t('Specify the alignment of the first item when the timline is in the horizontal mode'),
    );

    $form['visibleItems'] = array(
      '#type' => 'textfield',
      '#title' => t('Visible Items'),
      '#default_value' => $this->options['visibleItems'],
      '#description' => t('Specify the max number of stories to display at a time.'),
    );

    $form['moveItems'] = array(
      '#type' => 'textfield',
      '#title' => t('Move Items'),
      '#default_value' => $this->options['moveItems'],
      '#description' => t('When using the timeline in horizontal mode, define how many items to move when clicking a navigation button.'),
    );

    $form['startIndex'] = array(
      '#type' => 'textfield',
      '#title' => t('Start Index'),
      '#default_value' => $this->options['startIndex'],
      '#description' => t('When using the timeline in horizontal mode, define which item the timeline should start at.'),
    );

    $form['rtlMode'] = array(
      '#type' => 'select',
      '#title' => t('rtlMode'),
      '#options' => [
        TRUE => t('True'),
        FALSE => t('False'),
      ],
      '#default_value' => $this->options['rtlMode'],
      '#description' => t('When using the timeline in horizontal mode, this defines whether the timeline should start from the right. This overrides the startIndex setting.'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function render() {
    libraries_load('timeline');
    drupal_add_js([
      'min_timeline' => [
        'mode' => $this->options['mode'],
        'forceVerticalMode' => $this->options['forceVerticalMode'],
        'verticalTrigger' => $this->options['verticalTrigger'],
        'verticalStartPosition' => $this->options['verticalStartPosition'],
        'horizontalStartPosition' => $this->options['horizontalStartPosition'],
        'visibleItems' => $this->options['visibleItems'],
        'moveItems' => $this->options['moveItems'],
        'startIndex' => $this->options['startIndex'],
      ],
    ], 'setting');
    drupal_add_js(drupal_get_path('module', 'min_timeline') . '/js/min_timeline.js');
    return parent::render();
  }

  /**
   * Validate whether this plugin is configured correctly.
   *
   * @return array
   *   The list of errors to be displayed.
   */
  public function validate() {
    $errors = [];

    $row_plugin = get_class($this->row_plugin);
    if (!in_array($row_plugin, ['min_timeline_row_plugin'])) {
      $errors[] = t('You have not selected an appropriate row plugin.');
    }
    return $errors;
  }

}
